# `xm`

This directory contains the Launch API base classes and common implementations
that various experiment schedulers (local or provided as a service) and
executors (Docker, Kubernetes, Vertex AI etc) implement.
